import requests
import os
import json


def output(content, index):
    per = content["Series"][0]["OBSERVATIONS"][index]["TIME_PERIOD"]
    val = content["Series"][0]["OBSERVATIONS"][index]["OBS_VALUE"]
    print(per, val)


def get_content(url):
    response = requests.get(url)
    if response.status_code == 200:
        content = json.loads(response.content)
    return content


def desc_grupo(content, grupo):
    ocupado_2021 = int(content["Series"][0]["OBSERVATIONS"][0]["OBS_VALUE"])
    ocupado_2020 = int(content["Series"][0]["OBSERVATIONS"][4]["OBS_VALUE"])
    salida = f"La población {grupo} fue de {ocupado_2021}, cifra menor en {ocupado_2021 - ocupado_2020} con respecto al mismo trimestre del año anterior."
    print(salida)


inegi_token = os.environ["INEGI_TOKEN"]


def get_trimester_pea(trimester):
    pea = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/289244/es/0700/false/BIE/2.0/{inegi_token}?type=json"
    trimester_pea = get_trimester_indicator(pea, trimester)
    return trimester_pea


def get_trimester_employed_women(trimester):
    url_employed_women = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/446918/es/0700/false/BIE/2.0/{inegi_token}?type=json"
    trimester_employed_women = get_trimester_indicator(url_employed_women, trimester)
    return trimester_employed_women


def get_trimester_indicator(url, trimester):
    content = get_content(url)
    trimester_indicator = int(content["Series"][0]["OBSERVATIONS"][trimester]["OBS_VALUE"])
    return trimester_indicator


def get_trimester_employed_men(trimester):
    url_employed_men = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/446744/es/0700/false/BIE/2.0/{inegi_token}?type=json"
    trimester_employed_men = get_trimester_indicator(url_employed_men, trimester)
    return trimester_employed_men


def get_trimester_underemployed(trimester):
    url_underemployed = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/289278/es/0700/false/BIE/2.0/{inegi_token}?type=json"
    trimester_underemployed = get_trimester_indicator(url_underemployed, trimester)
    return trimester_underemployed



import os
import clean_enoa as ce



inegi_token = os.environ["INEGI_TOKEN"]
ocupada_hombres = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/446744/es/0700/false/BIE/2.0/{inegi_token}?type=json"
ocupada_mujeres = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/446918/es/0700/false/BIE/2.0/{inegi_token}?type=json"
pea = f"https://www.inegi.org.mx/app/api/indicadores/desarrolladores/jsonxml/INDICATOR/289244/es/0700/false/BIE/2.0/{inegi_token}?type=json"

content = ce.get_content(ocupada_mujeres)
ce.output(content, 0)
ce.output(content, 4)
ce.desc_grupo(content, "ocupada de mujeres")

content = ce.get_content(ocupada_hombres)
ce.output(content, 0)
ce.output(content, 4)
ce.desc_grupo(content, "ocupada de hombres")

content = ce.get_content(pea)
ce.output(content, 0)
ce.output(content, 4)
ce.desc_grupo(content, "económicamente activa")

last_trimester_employed_population = ce.get_trimester_employed_men(0) + ce.get_trimester_employed_women(0)
text_employed_population = f"La población ocupada fue {last_trimester_employed_population}."
print(text_employed_population)

last_trimester_unemployed_population = ce.get_trimester_pea(0) - ce.get_trimester_employed_men(0) - ce.get_trimester_employed_women(0)
text_unemployed_population = f"La población desocupada fue {last_trimester_unemployed_population}."
print(text_unemployed_population)

last_trimester_underemployed_population = ce.get_trimester_underemployed(0)
text_underemployed_population = f"La población subocupada fue {last_trimester_unemployed_population}."
print(text_underemployed_population)


#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['clean_enoa']

package_data = \
{'': ['*']}

setup(name='clean_enoa',
      version='0.1.0',
      description='This package makes requests to INEGI about unemployment in Mexico',
      author='Nepo Rojas • GECI',
      author_email='nepo.rojas@islas.org.mx',
      url='https://github.com/nepito/clean-enoa',
      packages=packages,
      package_data=package_data,
      python_requires='>=3',
     )



import clean_enoa as ce


content = {
    "Series": [
        {
            "OBSERVATIONS": [
                {"TIME_PERIOD": 1, "OBS_VALUE": 1},
                {"TIME_PERIOD": 2, "OBS_VALUE": 2},
                {"TIME_PERIOD": 3, "OBS_VALUE": 3},
                {"TIME_PERIOD": 4, "OBS_VALUE": 4},
                {"TIME_PERIOD": 5, "OBS_VALUE": 5},
            ]
        }
    ]
}


def test_output(capsys):  # or use "capfd" for fd-level
    ce.output(content, 1)
    captured = capsys.readouterr()
    assert captured.out == "2 2\n"


def test_desc_grupo(capsys):
    ce.desc_grupo(content, "ocupada de grupo")
    captured = capsys.readouterr()
    assert (
        captured.out
        == "La población ocupada de grupo fue de 1, cifra menor en -4 con respecto al mismo trimestre del año anterior.\n"
    )


class Requests:
    def __init__(self):
        self.status_code = 200
        self.content = "respuesta"


def test_get_content(mocker):
    def get(url):
        return Requests()

    mocker.patch("requests.get", get)

    def loads(respuesta):
        return {"hola": 2}

    mocker.patch("json.loads", loads)
    contenido = ce.get_content("url")
    assert contenido == {"hola": 2}


def tests_get_trimester_pea():
    expected_pea = 55385133
    assert_trimester_indicator(expected_pea, ce.get_trimester_pea, 0)
    expected_pea = 57328364
    assert_trimester_indicator(expected_pea, ce.get_trimester_pea, 4)


def tests_get_trimester_employed_women():
    expected_employed_women = 20302109
    assert_trimester_indicator(expected_employed_women, ce.get_trimester_employed_women, 0)
    expected_employed_women = 21868095
    assert_trimester_indicator(expected_employed_women, ce.get_trimester_employed_women, 4)


def tests_get_trimester_employed_men():
    expected_employed_men = 32671161
    assert_trimester_indicator(expected_employed_men, ce.get_trimester_employed_men, 0)
    expected_employed_men = 33484209
    assert_trimester_indicator(expected_employed_men, ce.get_trimester_employed_men, 4)


def assert_trimester_indicator(expected, get_function, trimester):
    obtained = get_function(trimester)
    assert expected == obtained


def test_get_trimester_underemployed():
    expected_underemployed = 7320605
    assert_trimester_indicator(expected_underemployed, ce.get_trimester_underemployed, 0)
    expected_underemployed = 4685631
    assert_trimester_indicator(expected_underemployed, ce.get_trimester_underemployed, 4)
